@@ -17,14 +17,13 @@
 #include <gpe/pixmaps.h>
 #include <gpe/init.h>
 
-#include <libdm.h>
+#include <libdisplaymigration/displaymigration.h>
 
 #include "todo.h"
 
 static struct gpe_icon my_icons[] = {
   { "hide" },
   { "clean" },
-  { "properties" },
   { "icon", PREFIX "/share/pixmaps/gpe-todo.png" },
   { "tick" },
   { NULL, NULL }
@@ -32,8 +31,6 @@ static struct gpe_icon my_icons[] = {
 
 #define _(_x) gettext(_x)
 
-guint window_x = 240, window_y = 320;
-
 GtkWidget *the_notebook;
 GtkWidget *window;
 
@@ -46,20 +43,20 @@ open_window (void)
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  libdm_mark_window (window);
+  displaymigration_mark_window (window);
 
   top = top_level (window);
 
   gtk_container_add (GTK_CONTAINER (window), top);
 
-  g_signal_connect (G_OBJECT (window), "destroy",
+  g_signal_connect (G_OBJECT (window), "delete-event",
 		    G_CALLBACK (g_main_loop_quit), NULL);
 
   gtk_window_set_default_size (GTK_WINDOW (window), 240, 320);
   gtk_window_set_title (GTK_WINDOW (window), _("To-do list"));
   gpe_set_window_icon (window, "icon");
 
-  gtk_widget_show (window);
+  gtk_widget_show_all (window);
 }
 
 int
@@ -71,6 +68,7 @@ main(int argc, char *argv[])
   setlocale (LC_ALL, "");
 
   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 
   if (gpe_load_icons (my_icons) == FALSE)
@@ -79,7 +77,7 @@ main(int argc, char *argv[])
   if (todo_db_start ())
     exit (1);
 
-  libdm_init ();
+  displaymigration_init ();
 
   open_window ();
   
